From 8a3b39e2b66ab9f7d1f1ac65082980d1de8a9582 Mon Sep 17 00:00:00 2001
From: xdh <xiefantasy@qq.com>
Date: 星期三, 31 十月 2018 14:52:30 +0800
Subject: [PATCH] 4498 【后端】【1.2.0】增加【助战特定副本】的任务接口

---
 ServerPython/ZoneServerGroup/map1_8G/MapServer/MapServerData/Script/GameWorldLogic/FBProcess/GameLogic_FamilyWar.py |   12 ++++++++----
 1 files changed, 8 insertions(+), 4 deletions(-)

diff --git a/ServerPython/ZoneServerGroup/map1_8G/MapServer/MapServerData/Script/GameWorldLogic/FBProcess/GameLogic_FamilyWar.py b/ServerPython/ZoneServerGroup/map1_8G/MapServer/MapServerData/Script/GameWorldLogic/FBProcess/GameLogic_FamilyWar.py
index cdceac6..793c116 100644
--- a/ServerPython/ZoneServerGroup/map1_8G/MapServer/MapServerData/Script/GameWorldLogic/FBProcess/GameLogic_FamilyWar.py
+++ b/ServerPython/ZoneServerGroup/map1_8G/MapServer/MapServerData/Script/GameWorldLogic/FBProcess/GameLogic_FamilyWar.py
@@ -757,8 +757,12 @@
         warPlayer = GetFamilyWarPlayer(playerID)
         warPlayer.calcFightTimeTick = tick
         
+        faction = curPlayer.GetFaction()
+        if not faction:
+            GameWorld.Log("还未设置阵营的玩家暂不处理!可能是DoEnter中!", playerID)
+            continue
         # 检查坐标,防止作弊
-        factionIndex = GetFactionIndex(curPlayer.GetFaction())
+        factionIndex = GetFactionIndex(faction)
         centrePosX, centrePosY, radius = factionAreaInfo[factionIndex]
         curPosX, curPosY = curPlayer.GetPosX(), curPlayer.GetPosY()
         dist = GameWorld.GetDist(curPosX, curPosY, centrePosX, centrePosY)
@@ -767,8 +771,8 @@
         if dist > maxDist:
             posPoint = GameMap.GetEmptyPlaceInArea(centrePosX, centrePosY, radius)
             curPlayer.ResetPos(posPoint.GetPosX(), posPoint.GetPosY())
-            GameWorld.DebugLog("玩家不在营地范围内,强制拉回!curPos=(%s,%s),centerPos=(%s,%s), dist=%s > maxDist=%s" 
-                               % (curPosX, curPosY, centrePosX, centrePosY, dist, maxDist))
+            GameWorld.Log("玩家不在营地范围内,强制拉回!faction=%s,curPos=(%s,%s),centerPos=(%s,%s), dist=%s > maxDist=%s" 
+                          % (faction, curPosX, curPosY, centrePosX, centrePosY, dist, maxDist), playerID)
     return
 
 def __DoLogic_FB_Fighting(tick):
@@ -1264,7 +1268,7 @@
 # @param tick 时间戳
 # @return 无意义
 # @remarks
-def OnCollectOK(curPlayer, tick):
+def OnCollectOK(curPlayer, npcID, tick):
     tagObj = curPlayer.GetActionObj()
     if not tagObj:
         return

--
Gitblit v1.8.0